import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, Tabs, Radio, DatePicker,message } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import styles from '../style/GoodsList.less';
import moment from 'moment';
import router from 'umi/router';
import BuildSelect from '../../components/SelectButton/BuildSelect'
import XForm, { FieldTypes } from '../../components/XForm';
import Wangedit from '../../components/Wangedit/Wangedit'
import request from '../../utils/request'

const { MonthPicker, RangePicker, WeekPicker } = DatePicker;
/**
 *
 *
 * @param {*} props
 * @returns
 */
 const Edit = (props) => {
  const [ tab, changeTab ] = useState('basic')
  const dynamicId = props.location.query.dynamicId
  const [ dynamicData, setDynamicData ] = useState({})
  if(dynamicId){
    useEffect(() => {
      getDynamicData(dynamicId);
    },[])

  // 查询列表
  const getDynamicData = (dynamicId) => {
    request({
        url: '/api/admin/buildingDynamic/Details',
        method: 'GET',
        params: { dynamicId },
    }).then((data) => {
        console.log(data)
        setDynamicData(data)
    })
  }
  }

  const cancelPage = () =>{
    router.push({
      pathname: '/activity/ActivityList',
    });
  }

  const Basic = (props) => {
    const fields = [
      {
        label: '所属项目',
        name: 'buildingId',
        render: <BuildSelect />,
        value: dynamicData.buildingId,
        rules: [
          {required: true, message: '请选择所属项目'},
        ]
      },
      {
        label: '主图',
        name: 'imgUrl',
        type: FieldTypes.ImageUploader,
        value: dynamicData.imgUrl,
      },
      {
        label: '活动标题',
        name: 'title',
        type: FieldTypes.Text,
        value: dynamicData.title,
        rules: [
          {required: true, message: '请输入活动标题'},
        ]
      },
      {
        label: '活动时间',
        name: 'activityTime',
        type: FieldTypes.RangePicker,
        value: dynamicData.startDate != null ?  [moment(dynamicData.startDate,'YYYY-MM-DD'),moment(dynamicData.endDate,'YYYY-MM-DD')] : null,
        rules: [
          {required: true, message: '请选择活动时间'},
        ]
      },
      {
        label: '活动地点',
        name: 'address',
        type: FieldTypes.Text,
        value: dynamicData.address,
        rules: [
          {required: true, message: '请输入活动地点'},
        ]
      },
      {
        label: '活动人数',
        name: 'enlistNum',
        type: FieldTypes.Text,
        value: dynamicData.enlistNum,
        rules: [
          {required: true, message: '请输入活动人数'},
        ]
      },
      {
        label: '活动详情',
        name: 'desc',
        render: <Wangedit />,
        value: dynamicData.desc,
      },
      {
        label: '是否需要报名',
        name: 'isEnlist',
        render: <Radio.Group name="radiogroup">
                  <Radio value={1}>是</Radio>
                  <Radio value={0}>否</Radio>
                </Radio.Group>,
        value: dynamicData.isEnlist != null ? dynamicData.isEnlist-0 : 1,
      },
      {
        label: '报名时间',
        name: 'signupTime',
        type: FieldTypes.RangePicker,
        value: dynamicData.enlistStart != null ?  [moment(dynamicData.enlistStart,'YYYY-MM-DD'),moment(dynamicData.enlistEnd,'YYYY-MM-DD')] : null,
        rules: [
          {required: true, message: '请选择报名时间'},
        ]
      },
    ]
  
    const handleSubmit = val => { 
      let {activityTime,signupTime, ...submitValue} = val
      const [startDate, endDate] = activityTime
      submitValue.startDate = moment(startDate).format('YYYY-MM-DD');
      submitValue.endDate = moment(endDate).format('YYYY-MM-DD');
      const [enlistStart, enlistEnd] = signupTime
      submitValue.enlistStart = moment(enlistStart).format('YYYY-MM-DD');
      submitValue.enlistEnd = moment(enlistEnd).format('YYYY-MM-DD');
      console.log('submit data --->', submitValue)
      if(dynamicId){
        submitValue.dynamicId = dynamicId
        request({
          url: '/api/admin/buildingDynamic/update',
          method: 'PUT',
          data: submitValue,
        }).then((data) => {
          cancelPage()
        }).catch((err) => {
          message.info(err.msg || err.message)
        })
      }else{
        request({
          url: '/api/admin/buildingDynamic/add',
          method: 'POST',
          data: submitValue,
        }).then((data) => {
          cancelPage()
        }).catch((err) => {
          message.info(err.msg || err.message)
        })
      }
    }
    
    return <XForm onSubmit={handleSubmit} onCancel={cancelPage} fields={fields}></XForm>
  }
  
  const Poster = (props) => {
   return <div>Poster</div>
  }
 
  const Share = (props) => {
    return <div>Share</div>
  }

  return (
    <div>
      <div>
        <Radio.Group value={tab} buttonStyle="solid" onChange={e => changeTab(e.target.value)}>
          <Radio.Button value="basic">基本信息</Radio.Button>
          <Radio.Button value="poster">海报图片</Radio.Button>
          <Radio.Button value="share">分享设置</Radio.Button>
        </Radio.Group>
      </div>
      <div>
        { tab === 'basic' && <Basic /> }
        { tab === 'poster' && <Poster /> }
        { tab === 'share' && <Share /> }
      </div>
    </div>
  );
 }



export default Edit
