import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, Select, Modal, message, Card, Row, Col, Pagination, Alert } from 'antd';
import moment from 'moment';
import router from 'umi/router';
import request from '../../../utils/request';
import apis from '../../../services/apis';
import Styles from './style.less';
import NewsTypeSelect from '../../../components/SelectButton/NewTypeSelect'


const { Option } = Select;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
const { Meta } = Card;

const tempDate = [{ code: 's101' }]

/**
 *卡片
 *
 * @returns
 */
function CartBody(props) {
  const { data } = props

  const cancelPage = () =>{
    router.push({
      pathname: '/news/list/NewsList',
    });
  }

  // 查询列表
  const getList = (params) => {
    request({
        url: '/api/admin/taNews',
        method: 'GET',
        params: { ...params },
    }).then((data) => {
        cancelPage();
    })
  }

  //删除资讯
  const changeNewsListStatus = (newsId) => () => {
    Modal.confirm({
      title: '确认删除该资讯？',
      okText: '确认',
      cancelText: '取消',
      onOk() {
        request({
          url: '/api/admin/taNews/' + newsId,
          method: 'DELETE',
          // data: { ...row },
        }).then((data) => {
          message.info('操作成功！')
          getList({ pageNum: 1, pageSize: 10 });
        })
      }
    });
  }

  // 跳转到编辑资讯列表
  const toEditList = (newsId) => ()  => {
    router.push({
      pathname: '/news/list/editNewsList',
      query: {
        newsId
      },
    });
  }

  return (
          <Card
            hoverable
            style={{ minWidth: '400px', borderRadius: '12px', margin: '10px', boxShadow: '0px 0px 16px 2px rgba(0,0,0,0.12)' }}
            cover={<img alt="example" src={ data.newsImg } style={{ borderRadius: '12px 12px 0 0', width: '100%', height: '14vw' }}></img>}
            bodyStyle={{ padding: '10px 20px' }}
          >
            <p className={Styles.cardText}>
              <span className={Styles.title}>资讯类型</span>
              <span >：{ data.newsType.newsTypeName }</span>
              <span className={Styles.ediText} onClick={toEditList(data.newsId)}>
                编辑
                <Icon type="form" style={{ color: '#C0C4CC', marginLeft: '10px' }} />
              </span>
            </p>
            <p className={Styles.cardText}>
              <span className={Styles.title}>状态</span>
              <span >：{ data.newsStatus == 0 ? "已发布" : "未发布" }</span>
            </p>
            <p className={Styles.cardItem}>
              <span className={Styles.title}>阅读数量</span>
              <span > ：{ data.pvNum }</span>
            </p>
            <p className={Styles.cardItem}>
              <span className={Styles.title}>转发数量</span>
              <span>：{ data.shareNum }</span>
            </p>
            <p className={Styles.cardItem}>
              <span className={Styles.title}>点赞数量</span>     
              <span >：{ data.favorNum }</span>         
            </p>
            <p className={Styles.cardItem}>
              <span className={Styles.title}>收藏数量</span>
              <span >：{ data.saveNum }</span>
            </p>
            <p className={Styles.cardItem}>
              <span className={Styles.title}>录入时间</span>
              <span >：{ data.createDate }</span>
            </p>
            <p style={{ margin: '15px 0', position: 'relative', fontSize: '18px' }}>
              <span style={{ color: '#1990FF' }}>
                取消发布
                <Icon type="close-circle" style={{ color: '#C0C4CC', marginLeft: '8px' }} />
              </span>
              <span style={{
                color: '#FF4A4A', position: 'absolute', right: '0',
              }} onClick={changeNewsListStatus(data.newsId)}>
                删除
                <Icon type="rest" style={{ color: '#C0C4CC', marginLeft: '8px' }} />
              </span>
            </p>
          </Card>
  )
}

/**
 *
 *
 * @param {*} props
 * @returns
 */
function body(props) {
  const { getFieldDecorator } = props.form

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [dataSource, setDataSource] = useState({ records: [] })

  // eslint-disable-next-line react-hooks/rules-of-hooks
  useEffect(() => {
    getList({ pageNum: 1, pageSize: 6 })
  }, [])

  function getList(params) {
    // 网路请求
    request({ ...apis.news.getList, params: { ...params } }).then(res => {
      setDataSource(res)
    }).catch(err => {
      // eslint-disable-next-line no-unused-expressions
      <Alert
        style={{
          marginBottom: 24,
        }}
        message={err}
        type="error"
        showIcon
      />
    })
  }

  // 提交事件
  function handleSubmit(e) {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        // eslint-disable-next-line no-console
        console.log('提交数据: ', values)
        const { startDate } = values
        getList({ pageNum: 1, pageSize: 9, ...values })
      }
    });
  }

  // 跳转到编辑资讯列表
  const toEditList = (id) => ()  => {
    router.push({
      pathname: '/news/list/editNewsList',
      query: {
        id
      },
    });
  }


  // Change 事件
  function handleSelectChange(e) {
    // eslint-disable-next-line no-console
    console.log(e)
  }

  // 分页
  function onChange(pageNumber) {
    // eslint-disable-next-line react-hooks/rules-of-hooks
      getList({ pageNum: pageNumber, pageSize: 9 })
  }

  function getDate(value, dateString) {
    // moment(value).format('YYYY-MM-DD HH:mm:ss')
    console.log(value, dateString)
  }

  return (
    <>
      <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>

        <Form.Item>
          {getFieldDecorator('city')(
            <Select style={{ width: '180px' }} placeholder="请选择城市" onChange={handleSelectChange}>
            </Select>,
          )}
        </Form.Item>

        <Form.Item>
          {getFieldDecorator('project')(
            <Select style={{ width: '180px' }} placeholder="请选择项目" onChange={handleSelectChange}>
            </Select>,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('title')(
            <Input
              prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
              placeholder="请输入标题"
            />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('buildingId')(
            <NewsTypeSelect />,
          )}
        </Form.Item>       
        <Form.Item>
          {getFieldDecorator('newsStatus')(
            <Select style={{ width: '180px' }} placeholder="状态" onChange={handleSelectChange}>
              <Option value="0">已发布</Option>
              <Option value="1">未发布</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item>
          <Button type="primary" htmlType="submit" className={Styles.SubmitButton}>
            搜索
          </Button>
        </Form.Item>
      </Form>
      <Button type="primary" className={Styles.addButton} onClick={toEditList()}>
        新增
      </Button>

      {/* 卡片内容，显示楼盘项目  */}
      <Row style={{ padding: ' 0 10px' }}>
        {
          dataSource.records.map((item, index) => (
              <Col span={8}>
                <CartBody data={item} key={item.buildingId}/>
              </Col>
            ))
        }
      </Row>
      {/* 分页 */}
      <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
        <Pagination showQuickJumper defaultCurrent={1} total={dataSource.total} onChange={onChange} />
      </div>
    </>
  );
}
const WrappedBody = Form.create({ name: 'body' })(body);

export default WrappedBody
